@@ -7,6 +7,10 @@ import logging
 import tempfile
 import inspect
 
+try:
+    RecursionError
+except NameError:
+    RecursionError = RuntimeError
 
 def get_package_versions():
     try:
@@ -52,6 +56,7 @@ from .utils import create_formatted_exception
 from .utils import read_bytes
 from .utils import raise_with_traceback
 from .utils import byte_string
+from .utils import value_repr
 
 
 log = logging.getLogger('chameleon.template')
@@ -121,6 +126,10 @@ class BaseTemplate(object):
     # time. When not set, this is only required at evaluation time.
     strict = True
 
+    # This should return a value string representation for exception
+    # formatting.
+    value_repr = staticmethod(value_repr)
+
     def __init__(self, body=None, **config):
         self.__dict__.update(config)
 
@@ -181,6 +190,8 @@ class BaseTemplate(object):
         stream = self.output_stream_factory()
         try:
             self._render(stream, econtext, rcontext)
+        except RecursionError:
+            raise
         except:
             cls, exc, tb = sys.exc_info()
             errors = rcontext.get('__error__')
@@ -191,7 +202,7 @@ class BaseTemplate(object):
                         formatter._errors.extend(errors)
                     raise
 
-                formatter = ExceptionFormatter(errors, econtext, rcontext)
+                formatter = ExceptionFormatter(errors, econtext, rcontext, self.value_repr)
 
                 try:
                     exc = create_formatted_exception(
